@@ -1,15 +1,48 @@
-#include <config.h>
-#include <gnome.h>
-#include "logview.h"
-#include <string.h>
-#include <sys/types.h>
-#include <regex.h>
+/*  ----------------------------------------------------------------------
+
+    Copyright (C) 1998  Cesar Miquel  (miquel@df.uba.ar)
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    ---------------------------------------------------------------------- */
+
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <stdlib.h>
+#include <string.h>
+#include <regex.h>
+#include "logview.h"
 #include "desc_db.h"
 
 #define MAX_NUM_MATCHES     10
 #define DELIM               ":"
 
+typedef struct
+{
+  char *regexp;
+  GList *matching;
+} ProcessDB;
+
+typedef struct
+{
+  char *text;
+  char tag[50];
+} DescriptionEntry;
+
+static void free_database (GList **db);
+static void print_db (GList *db);
 
 /* ----------------------------------------------------------------------
    NAME:        read_regexp_db
